==> kdepim_4.10.2.orig.tar.xz: kdepim-4.10.2/korganizer/docprefs.h <==
/*
  This file is part of KOrganizer.

  Copyright (c) 2001 Cornelius Schumacher <schumacher@kde.org>
  Copyright (c) 2005 Rafal Rzepecki <divide@users.sourceforge.net>

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License along
  with this program; if not, write to the Free Software Foundation, Inc.,
  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.

  As a special exception, permission is given to link this program
  with any edition of Qt, and distribute the resulting executable,
  without including the source code for Qt in the source distribution.
*/

#ifndef KORG_DOCPREFS_H
#define KORG_DOCPREFS_H

#include <QString>

class KConfig;

class DocPrefs
{
  public:
    DocPrefs( const QString &type="general" );
    ~DocPrefs();

    void setDoc( const QString &identifier );
    QString doc() const;

    bool readBoolEntry( const QString &identifier ) const;
    void writeBoolEntry( const QString &identifier, bool value );
    int readNumEntry( const QString &identifier ) const;
    void writeNumEntry( const QString &identifier, int value );

  private:
    static KConfig *mConfig;
    QString mDocId;
};

#endif

==> kdepim-4.10.90.tar.xz: kdepim-4.10.90/korganizer/docprefs.h <==
/*
  This file is part of KOrganizer.

  Copyright (c) 2001 Cornelius Schumacher <schumacher@kde.org>
  Copyright (c) 2005 Rafal Rzepecki <divide@users.sourceforge.net>

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License along
  with this program; if not, write to the Free Software Foundation, Inc.,
  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.

  As a special exception, permission is given to link this program
  with any edition of Qt, and distribute the resulting executable,
  without including the source code for Qt in the source distribution.
*/

#ifndef KORG_DOCPREFS_H
#define KORG_DOCPREFS_H

#include <QString>

class KConfig;

class DocPrefs
{
  public:
    explicit DocPrefs( const QString &type="general" );
    ~DocPrefs();

    void setDoc( const QString &identifier );
    QString doc() const;

    bool readBoolEntry( const QString &identifier ) const;
    void writeBoolEntry( const QString &identifier, bool value );
    int readNumEntry( const QString &identifier ) const;
    void writeNumEntry( const QString &identifier, int value );

  private:
    static KConfig *mConfig;
    QString mDocId;
};

#endif
